pub enum RecvTimeoutError {
Timeout,
Disconnected,
}Expand description
Error returned by recv_timeout.
Variants
Timeout
The timeout elapsed before a message arrived.
Disconnected
All senders have been dropped and no messages remain.
Implementations
Sourceimpl RecvTimeoutError
impl RecvTimeoutError
Sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if this error is the Timeout variant.
Sourcepub fn is_disconnected(&self) -> bool
pub fn is_disconnected(&self) -> bool
Returns true if this error is the Disconnected variant.